Coverage report

# Coverage report: 99%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 490 | 5 | 0 | 99%
/home/kale/research/software/projects/bio96/bio96/__init__.py | 4 | 0 | 0 | 100%
/home/kale/research/software/projects/bio96/bio96/load.py | 257 | 1 | 0 | 99%
/home/kale/research/software/projects/bio96/bio96/util.py | 62 | 0 | 0 | 100%
/home/kale/research/software/projects/bio96/bio96/verify.py | 167 | 4 | 0 | 98%

No items found using the specified filter.